==> next-typed-pages-0.3.0-0.tgz: package/src/nextPages.ts <==
import { $index, $route } from './symbols'
import {
  HasIndexSymbol,
  MappedRouteOptions,
  MappedRouteValue,
  RouteOptions,
} from './types'
import { isDynamicRouteKey, joinPath } from './utils'

const mapRouteValue = <R extends typeof $route | RouteOptions>(
  path: string,
  route: R,
): MappedRouteValue<R, any> => {
  return (route === $route
    ? path || '/'
    : mapRouteOptions(path, route as RouteOptions)) as MappedRouteValue<R, any>
}

const mapRouteOptions = <T extends RouteOptions>(
  prevPath: string,
  options: T,
): MappedRouteOptions<T, any> => {
  const optionEntries = Object.entries(options)

  const [dynamicRoutePath, dynamicRoute] =
    optionEntries.find(([key]) => isDynamicRouteKey(key)) ?? []

  const dynamicRouteFunction = dynamicRoute
    ? (key: string | null) =>
        mapRouteValue(
          joinPath(prevPath, key ?? dynamicRoutePath!),
          dynamicRoute,
        )
    : {}

  const mappedOptions = Object.fromEntries(
    optionEntries.map(
      ([key, route]) =>
        [key, mapRouteValue(joinPath(prevPath, key), route)] as const,
    ),
  )

  return Object.assign(dynamicRouteFunction, mappedOptions, {
    [$index]: prevPath,
  }) as MappedRouteOptions<T, any>
}

export const nextPages = <T extends RouteOptions>(
  options: T,
): MappedRouteOptions<T, ''> => mapRouteOptions('', options)

export const isSubpathOf = (
  pathname: string,
  routeOptions: HasIndexSymbol<string>,
) => {
  const directoryPath = routeOptions[$index]
  return pathname === directoryPath || pathname.startsWith(directoryPath + '/')
}

==> next-typed-pages-0.3.1.tgz: package/src/nextPages.ts <==
import { $index, $route } from './symbols'
import {
  HasIndexSymbol,
  MappedRouteOptions,
  MappedRouteValue,
  RouteOptions,
  UsePagesRouter,
} from './types'
import { isDynamicRouteKey, joinPath } from './utils'
import { NextRouter, useRouter } from 'next/router'
import { Merge } from 'type-fest'

const mapRouteValue = <R extends typeof $route | RouteOptions>(
  path: string,
  route: R,
): MappedRouteValue<R, any> => {
  return (route === $route
    ? path || '/'
    : mapRouteOptions(path, route as RouteOptions)) as MappedRouteValue<R, any>
}

const mapRouteOptions = <T extends RouteOptions>(
  prevPath: string,
  options: T,
): MappedRouteOptions<T, any> => {
  const optionEntries = Object.entries(options)

  const [dynamicRoutePath, dynamicRoute] =
    optionEntries.find(([key]) => isDynamicRouteKey(key)) ?? []

  const dynamicRouteFunction = dynamicRoute
    ? (key: string | null) =>
        mapRouteValue(
          joinPath(prevPath, key ?? dynamicRoutePath!),
          dynamicRoute,
        )
    : {}

  const mappedOptions = Object.fromEntries(
    optionEntries.map(
      ([key, route]) =>
        [key, mapRouteValue(joinPath(prevPath, key), route)] as const,
    ),
  )

  return Object.assign(dynamicRouteFunction, mappedOptions, {
    [$index]: prevPath,
  }) as MappedRouteOptions<T, any>
}

export const nextPages = <T extends RouteOptions>(options: T) => {
  const pages: MappedRouteOptions<T, ''> = mapRouteOptions('', options)
  const usePagesRouter = () => useRouter() as UsePagesRouter<T>

  return { pages, usePagesRouter }
}

export const isSubpathOf = (
  pathname: string,
  routeOptions: HasIndexSymbol<string>,
) => {
  const directoryPath = routeOptions[$index]
  return pathname === directoryPath || pathname.startsWith(directoryPath + '/')
}
